#! /bin/sh
# @(#)updatemidas1.sh	1.1 (ESO-IPG) 07/12/91 14:16:06
# .COPYRIGHT: Copyright (c) 1988 European Southern Observatory,
#                                         all rights reserved
# .TYPE           command
# .NAME           updatemidas1.sh
# .LANGUAGE       shell script
# .ENVIRONMENT    Unix Systems. Executable under SHELL and C-SHELL
# .COMMENTS       Installation procedure of the MIDAS system starting from
#                 scratch.
#                 Usage: installmidas system [options]
#
# .REMARKS        The external variable $MIDASHOME and $MIDVERS must be set 
#
# .AUTHOR         Carlos Guirao
# .VERSION 1.1    25-Oct-1989:		Implementation
# .VERSION 2.3    05-Dec-1989:		Adding "echo" definition.
# .VERSION 2.4    910219:		Removing SYSTEM NAME as argument
echo=echo
if [ "`echo -n`" = "-n" ] ; then
        SV_NONL="\c"
else
        echo="echo -n"
fi

if [ $MIDASHOME ]
then
        continue
else
        echo "\$MIDASHOME undefined"
        echo "Please, set \$MIDASHOME and \$MIDVERS before running: $0"
        exit
fi
if [ $MIDVERS ]
then
        continue
else
        echo "\$MIDVERS is undefined"
        echo "Please, set \$MIDASHOME and \$MIDVERS before running: $0"
        exit
fi

MID_INSTALL=$MIDASHOME/$MIDVERS/install/unix
cd $MID_INSTALL

clear
if [ ! -f "$MID_INSTALL/midas.cnf" ] ; then
	echo ""
	echo "ERROR: The configuration file <midas.cnf> does not exist.."
	echo "       Run <configmidas> and select a configuration for MIDAS."
	exit 1
fi

if [ ! -f "$MIDASHOME/local/make_options" ] ; then
	echo ""
	echo "ERROR: The file <$MIDASHOME/local/make_options> does not exist."
	echo "       Run <preinstall> before to continue with updatemidas."
	exit 1
fi

if [ ! -d "$MIDASHOME/tmp" ] ; then
	echo "Directory: <$MIDASHOME/tmp> does not exist."
	mkdir $MIDASHOME/tmp
	if [ $? != 0 ] ; then
		echo "ERROR: <$MIDASHOME/tmp> cannot be created."
		echo "	     Ask your system manager. EXIT."
		exit 1
	fi
	echo "<$MIDASHOME/tmp> created."
	chmod 777 $MIDASHOME/tmp
	exit
fi

if [ ! -f "$MIDASHOME/$MIDVERS/lib/mathlib.a" ] ; then
	echo "WARNING: NAG mathematical library does not exist as"
	echo "         $MIDASHOME/$MIDVERS/lib/mathlib.a."
	echo "         If you have it somewhere, then copy it to that name"
	echo "         or make a link between them." 
	echo ""
	echo "         If you do not have it, then continue with the"
	echo "         installation but some executables may not be created"
	echo "         because of this lack."
	echo ""
	$echo "Do you want to continue ? [yn]? (y): " $SV_NONL
	read answ
	if [ -z "$answ" ]; then
	    answ=y
	fi
	if [ "$answ" != "y" -a "$answ" != "Y" ]; then
        	exit 0
	fi
fi

if [ -f "$MIDASHOME/local/README" ] ; then
	cat $MIDASHOME/local/README
fi

clear
echo ""
echo "MIDAS UPDATE PROCEDURE"
echo "======================"
echo "MIDASHOME: $MIDASHOME"
echo "MIDVERS:   $MIDVERS"
echo "MAKE_OPTIONS:"
awk -F# '{ if ($1 != "") {printf "\t  %s\n",$1} }' $MIDASHOME/local/make_options
echo ""
echo "NOTE: Updatemidas will only compile and link those files and"
echo "      executables not updated in previous installation" 
echo "      It will run in background and the output will be sent to"
echo "      the file <$MIDASHOME/tmp/update.$$>"
echo ""
$echo "Do you want to continue [yn]? (y): " $SV_NONL
read answ
if [ -z "$answ" ]; then
    answ=y
fi
if [ "$answ" != "y" -a "$answ" != "Y" ]
then
    echo "Bye"
    exit 0
fi

/bin/time /bin/sh $MID_INSTALL/updatemidas -i > $MIDASHOME/tmp/update.$$ 2>&1 &
echo "Running updatemidas in background"
echo "Results are coming in $MIDASHOME/tmp/update.$$"
